@@ -48,7 +48,6 @@ def printcyan(text):
   print(CYAN + text + RESET)
 def printunderline(text):
   print(UNDERLINE + text + RESET)
-
 def sp(text):
   for char in text:
     print(char, end = "")
@@ -56,14 +55,11 @@ def sp(text):
     sys.stdout.flush()
 def clear():
   print("\033c", end = "")
-
 class color():
   def spc(text,color = None): # put try statement
-      sun = 0
       if color == None:
-        print("Please do fill out the color text box")
-        sun = 1  
-      elif color == "red":
+        print("Please fill out the color text box")
+      elif color == 'red':
         for char in text:
           print(RED + char, end = "")
           time.sleep(0.05)
@@ -105,8 +101,6 @@ class color():
           sys.stdout.flush()
       else:
         print(f'Error: unknown text formatting: {color}')
-def ysn():
-  print("[y/n]", end = "")
 class math():
   def add(num1, num2):
     try:
@@ -178,3 +172,9 @@ class math():
       print("ERROR")
   
   
+def out(text ,end = None):
+  if end == None:
+    end = "\n"
+  else:
+    pass
+  print(text, end = str(end))
\ No newline at end of file
